@@ -126,9 +126,9 @@ class Client:
                 self.post_limit = int(headers["requests-remaining"])
                 self.post_timeout = int(headers["requests-reset"])
             except KeyError:
-                self.set_limit = 0
-                self.set_timeout = 200
-                raise RateLimitError(f"Rate limited by server but internal values not updated. Please wait {self.set_timeout}")
+                self.post_limit = 0
+                self.post_timeout = 200
+                raise RateLimitError(f"Rate limited by server but internal values not updated. Please wait {self.post_timeout}")
             return
 
     def get_limits(self):
